decode_track_code

Function decode_track_code 

pub fn decode_track_code(track_code: &str) -> Option<Track>
Decodes the given track code and yields a struct containing the track name, track author, and the (raw binary) track data. Returns None if something failed in the process.