Module v6

Module v6 

Structs

Block
Part
TrackInfo

Enums

Direction
Environment

Constants

CP_IDS
START_IDS

Functions

decode_track_code
Decodes the given track code and yields a struct containing the track name, track author, and the (raw binary) track data. Returns None if something failed in the process.
decode_track_data
Decodes the (raw binary) track data into a struct representing everything that is in the data.
encode_track_code
Encodes the given track struct into a track code. Returns None if something failed in the process.
encode_track_data
Encodes the TrackInfo struct into raw binary data.
export_to_id
Computes the track ID for a given track code. Returns None if something failed in the process.