pub fn decode_track_data(data: &[u8]) -> Option<TrackInfo>Expand description
Decodes the (raw binary) track data into a struct representing everything that is in the data.
Fields of all involved structs correspond exactly to how
the data is stored in Polytrack itself.
Returns None if the data is not valid track data.