pub fn encode_track_code(track: &Track) -> Option<String>Expand description
Encodes the given track struct into a track code.
Returns None if something failed in the process.
Output might differ slightly from Polytrack’s output because of Zlib shenanigans, but is still compatible.