Structs
Enums
Constants
Functions
- decode_
track_ code - Decodes the given track code and yields a struct containing the track name, track author, and the (raw binary) track data.
Returns
Noneif something failed in the process. - decode_
track_ data - Decodes the (raw binary) track data into a struct representing everything that is in the data.
- encode_
track_ code - Encodes the given track struct into a track code.
Returns
Noneif something failed in the process. - encode_
track_ data - Encodes the
TrackInfostruct into raw binary data. - export_
to_ id - Computes the track ID for a given track code. Returns
Noneif something failed in the process.